@@ -6,7 +6,17 @@ https://developers.meethue.com/develop/hue-api-v2/api-reference/#resource_groupe
 from dataclasses import dataclass
 from typing import Optional
 
-from .feature import AlertFeature, AlertFeaturePut, OnFeature
+from .feature import (
+    AlertFeature,
+    AlertFeaturePut,
+    ColorFeatureBase,
+    ColorTemperatureDeltaFeaturePut,
+    ColorTemperatureFeatureBase,
+    DimmingDeltaFeaturePut,
+    DimmingFeatureBase,
+    DynamicsFeaturePut,
+    OnFeature,
+)
 from .resource import ResourceTypes
 
 
@@ -34,4 +44,10 @@ class GroupedLightPut:
     """
 
     on: Optional[OnFeature] = None
+    dimming: Optional[DimmingFeatureBase] = None
+    dimming_delta: Optional[DimmingDeltaFeaturePut] = None
+    color_temperature: Optional[ColorTemperatureFeatureBase] = None
+    color_temperature_delta: Optional[ColorTemperatureDeltaFeaturePut] = None
+    color: Optional[ColorFeatureBase] = None
+    dynamics: Optional[DynamicsFeaturePut] = None
     alert: Optional[AlertFeaturePut] = None
